import * as ts from 'typescript';
export declare function getScriptKind(filePath: string, jsx: boolean): ts.ScriptKind;
export declare function getLanguageVariant(scriptKind: ts.ScriptKind): ts.LanguageVariant;
//# sourceMappingURL=getScriptKind.d.ts.map