import type { ParseSettings } from './index';
/**
 * This needs to be kept in sync with package.json in the typescript-eslint monorepo
 */
export declare const SUPPORTED_TYPESCRIPT_VERSIONS = ">=4.8.4 <5.9.0";
export declare function warnAboutTSVersion(parseSettings: ParseSettings, passedLoggerFn: boolean): void;
//# sourceMappingURL=warnAboutTSVersion.d.ts.map