import * as ts from 'typescript';
import type { ParseSettings } from '../parseSettings';
import type { ASTAndNoProgram } from './shared';
export declare function createSourceFile(parseSettings: ParseSettings): ts.SourceFile;
export declare function createNoProgram(parseSettings: ParseSettings): ASTAndNoProgram;
//# sourceMappingURL=createSourceFile.d.ts.map