export declare function addCandidateTSConfigRootDir(candidate: string): void;
export declare function clearCandidateTSConfigRootDirs(): void;
export declare function getInferredTSConfigRootDir(): string;
//# sourceMappingURL=candidateTSConfigRootDirs.d.ts.map