import type * as ts from 'typescript';
import type { ParseSettings } from '../parseSettings';
export declare function createProjectProgramError(parseSettings: ParseSettings, programsForProjects: readonly ts.Program[]): string[];
//# sourceMappingURL=createProjectProgramError.d.ts.map